SpacePy Case Studies — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »

# SpacePy Case Studies

The SpacePy team has prepared case studies showing how to reproduce the results from published papers using Python-based tools, including SpacePy. It is hoped that these extensively-documented examples will ease the transition to Python for space scientists.

Basic familiarity with programming and general computing tasks in your chosen environment is assumed, including editing text files, copying and deleting files, etc. No Python-specific knowledge is assumed, although it is recommended to at least skim the excellent Python tutorial.

- Paulikas and Blake revisited (Reeves et al. 2011)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »